Several fixes/improvements to directed tests.
Change-Id: Ieb32569ddbf5795d2ab3392165a7ddc22693dc62
[ROCm/hip commit: c4b602a0b9]
Этот коммит содержится в:
@@ -90,7 +90,7 @@ int main() {
|
||||
setenv("CUDA_VISIBLE_DEVICES",(char*)std::to_string(i).c_str(),1);
|
||||
if (devPCINum[i] != getDevicePCIBusNumRemote(0)) {
|
||||
std::cout << "The returned PciBusID is not correct"<< std::endl;
|
||||
std::cout << "Expected "<< devPCINum[i] << ", but get " << getDevicePCIBusNum << endl;
|
||||
std::cout << "Expected "<< devPCINum[i] << ", but get " << getDevicePCIBusNum(i) << endl;
|
||||
exit(-1);
|
||||
} else {
|
||||
continue;
|
||||
|
||||
@@ -38,8 +38,10 @@ int main()
|
||||
HIPCHECK(hipSetDevice(j));
|
||||
|
||||
for(int i=0;i<4;i++){
|
||||
flag = 1 < i;
|
||||
flag = 1 << i;
|
||||
printf ("Flag=%x\n", flag);
|
||||
HIPCHECK(hipSetDeviceFlags(flag));
|
||||
//HIPCHECK_API(hipSetDeviceFlags(flag), hipErrorInvalidValue);
|
||||
}
|
||||
|
||||
flag = 0;
|
||||
|
||||
@@ -90,6 +90,17 @@ void run(size_t size, hipStream_t stream1, hipStream_t stream2){
|
||||
HIPCHECK(hipDeviceSynchronize());
|
||||
HIPASSERT(Eh[10] = Ah[10] + 1.0f);
|
||||
HIPASSERT(Ehh[10] = Ahh[10] + 1.0f);
|
||||
|
||||
HIPCHECK(hipHostFree(Ah));
|
||||
HIPCHECK(hipHostFree(Bh));
|
||||
HIPCHECK(hipHostFree(Eh));
|
||||
HIPCHECK(hipHostFree(Ahh));
|
||||
HIPCHECK(hipHostFree(Bhh));
|
||||
HIPCHECK(hipHostFree(Ehh));
|
||||
HIPCHECK(hipFree(Cd));
|
||||
HIPCHECK(hipFree(Dd));
|
||||
HIPCHECK(hipFree(Cdd));
|
||||
HIPCHECK(hipFree(Ddd));
|
||||
}
|
||||
|
||||
int main(int argc, char **argv)
|
||||
|
||||
Ссылка в новой задаче
Block a user